@@ -17,7 +17,7 @@
  */
 
 #define NL_MAJOR 1
-#define NL_MINOR 0
+#define NL_MINOR 2
 #define NL_REV   7
-#define NL_DATE  "May 14, 2001"
-#define VERSION  "1.0.7"
+#define NL_DATE  "Sep 09, 2003"
+#define VERSION  "1.2.7"
